import * as https from 'node:https';
import type { Notice, NoticeDataSource } from './types';
import type { IoHelper } from '../io/private';
/**
 * A data source that fetches notices from the CDK notices data source
 */
export declare class WebsiteNoticeDataSourceProps {
    /**
     * The URL to load notices from.
     *
     * Note this must be a valid JSON document in the CDK notices data schema.
     *
     * @see https://github.com/cdklabs/aws-cdk-notices
     *
     * @default - official CDK notices
     */
    readonly url?: string | URL;
    /**
     * The agent responsible for making the network requests.
     *
     * Use this so set up a proxy connection.
     *
     * @default - uses the shared global node agent
     */
    readonly agent?: https.Agent;
}
export declare class WebsiteNoticeDataSource implements NoticeDataSource {
    private readonly ioHelper;
    /**
     * The URL notices are loaded from.
     */
    readonly url: any;
    private readonly agent?;
    constructor(ioHelper: IoHelper, props?: WebsiteNoticeDataSourceProps);
    fetch(): Promise<Notice[]>;
}
